@@ -778,6 +778,164 @@ def test_plan_handle_get(mocker, plan_json, config, response, monkeypatch):
     assert exit.value.code == 1
 
 
+def test_plan_handle_wait(mocker, plan_json, config, response, monkeypatch):
+    monkeypatch.setattr(
+        sys, "argv", ["tuxsuite", "plan", "wait", "1tOhlD2nkPsRNNTMB5Lj09n1IVQ"]
+    )
+    response.status_code = 200
+    response._content = plan_json
+    wait_req = mocker.patch("requests.get", return_value=response)
+    mocker.patch("tuxsuite.build.get_request", return_value=response)
+    mocked_plan_get = mocker.patch(
+        "tuxsuite.Plan.get_plan",
+        return_value={
+            "builds": {
+                "1qsx3vvpbsyQS7gVwfdwBHZzcCY": {
+                    "project": "tuxsuite/senthil",
+                    "uid": "1qsx3vvpbsyQS7gVwfdwBHZzcCY",
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "kconfig": ["defconfig"],
+                    "target_arch": "x86_64",
+                    "toolchain": "clang-nightly",
+                    "build_name": "",
+                    "client_token": "537c0a39-5919-48a3-96c2-31773aaae988",
+                    "environment": {},
+                    "make_variables": {},
+                    "targets": [],
+                    "git_repo": "https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git",
+                    "git_ref": "master",
+                    "git_sha": "454859c552da78b0f587205d308401922b56863e",
+                    "download_url": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCY/",
+                    "kernel_image": "",
+                    "user": "senthil.kumaran@linaro.org",
+                    "user_agent": None,
+                    "state": "finished",
+                    "result": "canceled",  # case: Plan Canceled
+                    "waited_by": ["1qsx5iBMtsjD24OgjWW9tatj4HG"],
+                    "errors_count": 1,
+                    "warnings_count": 4,
+                    "kernel_patch_file": None,
+                    "provisioning_time": "2021-11-01T19:38:31.161747",
+                    "running_time": None,
+                    "finished_time": None,
+                    "git_short_log": "454859c552da (\"Merge tag 'arc-5.12-rc7'\")",
+                    "kernel_image_name": "bzImage",
+                    "duration": 40,
+                    "build_status": "error",
+                    "tuxbuild_status": "complete",
+                    "kernel_version": "5.12.0-rc6",
+                    "status_message": "build canceled",
+                },
+                "1qsx3vvpbsyQS7gVwfdwBHZzcCR": {
+                    "project": "tuxsuite/senthil",
+                    "uid": "1qsx3vvpbsyQS7gVwfdwBHZzcCR",
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "kconfig": ["defconfig"],
+                    "target_arch": "x86_64",
+                    "toolchain": "clang-nightly",
+                    "build_name": "",
+                    "client_token": "537c0a39-5919-48a3-96c2-31773aaae988",
+                    "environment": {},
+                    "make_variables": {},
+                    "targets": [],
+                    "git_repo": "https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git",
+                    "git_ref": "master",
+                    "git_sha": "454859c552da78b0f587205d308401922b56863e",
+                    "download_url": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCR/",
+                    "kernel_image": "",
+                    "user": "senthil.kumaran@linaro.org",
+                    "user_agent": None,
+                    "state": "finished",
+                    "result": "unknown",  # case: result unknown
+                    "waited_by": ["1qsx5iBMtsjD24OgjWW9tatj4HF"],
+                    "errors_count": 1,
+                    "warnings_count": 4,
+                    "kernel_patch_file": None,
+                    "provisioning_time": "2021-11-01T19:38:31.161747",
+                    "running_time": None,
+                    "finished_time": None,
+                    "git_short_log": "454859c552da (\"Merge tag 'arc-5.12-rc7'\")",
+                    "kernel_image_name": "bzImage",
+                    "duration": 40,
+                    "build_status": "error",
+                    "tuxbuild_status": "complete",
+                    "kernel_version": "5.12.0-rc6",
+                    "status_message": "build running",
+                },
+            },
+            "tests": {
+                "1qsx5iBMtsjD24OgjWW9tatj4HE": {
+                    "project": "tuxsuite/senthil",
+                    "device": "qemu-x86_64",
+                    "uid": "1qsx5iBMtsjD24OgjWW9tatj4HE",
+                    "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
+                    "mcp_fw": None,
+                    "mcp_romfw": None,
+                    "modules": None,
+                    "parameters": None,
+                    "rootfs": None,
+                    "scp_fw": None,
+                    "scp_romfw": None,
+                    "fip": None,
+                    "tests": ["boot", "ltp-smoke"],
+                    "user": None,
+                    "user_agent": None,
+                    "state": "finished",
+                    "result": "pass",  # case: result pass
+                    "results": {"boot": "pass", "ltp-smoke": "pass"},
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "waiting_for": "1qsx3vvpbsyQS7gVwfdwBHZzcCX",
+                    "boot_args": None,
+                    "provisioning_time": "2021-04-08T11:46:53.297621",
+                    "running_time": "2021-04-08T11:46:54.355808",
+                    "finished_time": "2021-04-08T11:47:39.082080",
+                    "duration": 45,
+                },
+                "2qsx5iBMtsjD24OgjWW9tatj4HE": {
+                    "project": "tuxsuite/senthil",
+                    "device": "qemu-x86_64",
+                    "uid": "2qsx5iBMtsjD24OgjWW9tatj4HE",
+                    "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCX/bzImage",
+                    "ap_romfw": None,
+                    "mcp_fw": None,
+                    "mcp_romfw": None,
+                    "modules": None,
+                    "parameters": None,
+                    "rootfs": None,
+                    "scp_fw": None,
+                    "scp_romfw": None,
+                    "fip": None,
+                    "tests": ["boot", "ltp-smoke"],
+                    "user": None,
+                    "user_agent": None,
+                    "state": "finished",
+                    "result": "fail",  # case: result fail
+                    "results": {"boot": "fail", "ltp-smoke": "pass"},
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "waiting_for": "1qsx3vvpbsyQS7gVwfdwBHZzcCX",
+                    "boot_args": None,
+                    "provisioning_time": "2021-04-08T11:46:53.297621",
+                    "running_time": "2021-04-08T11:46:54.355808",
+                    "finished_time": "2021-04-08T11:47:39.082080",
+                    "duration": 45,
+                },
+            },
+        },
+    )
+
+    tuxsuite.cli.main()
+    mocked_plan_get.assert_called()
+    assert wait_req.call_count == 1
+
+    # Test failure case when the response is not 200
+    response.status_code = 500
+    wait_req = mocker.patch("requests.get", return_value=response)
+    with pytest.raises(NotImplementedError):
+        tuxsuite.cli.main()
+    assert wait_req.call_count == 1
+
+
 def test_plan_handle_cancel(mocker, plan_json, config, response, monkeypatch):
     monkeypatch.setattr(
         sys, "argv", ["tuxsuite", "plan", "cancel", "1tOhlD2nkPsRNNTMB5Lj09n1IVQ"]
