@@ -89,7 +89,7 @@ def test_plan_config(plan_config):
         "toolchain": "gcc-8",
     }
     assert cfg.plan[8]["tests"] == [
-        {"device": "qemu-i386"},
+        {"device": "qemu-i386", "parameters": {"HELLO": "WORLD"}},
         {
             "device": "qemu-i386",
             "tests": ["ltp-syscalls"],
@@ -105,6 +105,11 @@ def test_plan_config(plan_config):
             "tests": ["ltp-syscalls"],
             "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 3},
         },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-commands"],
+            "parameters": {"HELLO": "WORLD", "SHARD_NUMBER": 1, "SHARD_INDEX": 1},
+        },
     ]
 
     assert cfg.plan[9]["build"] == {
@@ -113,7 +118,7 @@ def test_plan_config(plan_config):
         "toolchain": "gcc-9",
     }
     assert cfg.plan[9]["tests"] == [
-        {"device": "qemu-i386"},
+        {"device": "qemu-i386", "parameters": {"HELLO": "WORLD"}},
         {
             "device": "qemu-i386",
             "tests": ["ltp-syscalls"],
@@ -129,6 +134,11 @@ def test_plan_config(plan_config):
             "tests": ["ltp-syscalls"],
             "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 3},
         },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-commands"],
+            "parameters": {"HELLO": "WORLD", "SHARD_NUMBER": 1, "SHARD_INDEX": 1},
+        },
     ]
 
     assert cfg.plan[10]["build"] == {
@@ -137,7 +147,7 @@ def test_plan_config(plan_config):
         "toolchain": "gcc-10",
     }
     assert cfg.plan[10]["tests"] == [
-        {"device": "qemu-i386"},
+        {"device": "qemu-i386", "parameters": {"HELLO": "WORLD"}},
         {
             "device": "qemu-i386",
             "tests": ["ltp-syscalls"],
@@ -153,6 +163,11 @@ def test_plan_config(plan_config):
             "tests": ["ltp-syscalls"],
             "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 3},
         },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-commands"],
+            "parameters": {"HELLO": "WORLD", "SHARD_NUMBER": 1, "SHARD_INDEX": 1},
+        },
     ]
 
     assert cfg.plan[11]["build"] is None
@@ -179,12 +194,14 @@ def test_plan_config(plan_config):
         },
         {
             "kernel": "https://storage.tuxboot.com/riscv64/Image",
+            "bios": "https://storage.tuxboot.com/riscv64/fw_jump.elf",
             "device": "qemu-riscv64",
             "tests": ["ltp-smoke"],
         },
         {
             "kernel": "https://storage.tuxboot.com/x86_64/bzImage",
             "device": "qemu-x86_64",
+            "rootfs": "https://storage.tuxboot.com/x86_64/rootfs.ext4.zst",
             "tests": ["ltp-smoke"],
         },
     ]
@@ -265,7 +282,11 @@ def test_submit(config, plan_config, mocker):
     def post(url, headers, data):
         assert "Authorization" in headers
         if url == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/plans":
-            assert data == {"description": "A simple plan", "name": "Simple plan"}
+            assert data == {
+                "description": "A simple plan",
+                "name": "Simple plan",
+                "is_public": True,
+            }
             return {"uid": "my-plan-uid"}
         if url == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/builds":
             assert isinstance(data, dict)
@@ -288,7 +309,7 @@ def test_submit(config, plan_config, mocker):
             return builds
         if url == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/tests":
             assert isinstance(data, list)
-            assert len(data) == 27
+            assert len(data) == 30
 
             tests = []
             for p in cfg.plan:
@@ -313,15 +334,18 @@ def test_submit(config, plan_config, mocker):
             assert data[10]["waiting_for"] == "my-build-08"
             assert data[11]["waiting_for"] == "my-build-08"
             assert data[12]["waiting_for"] == "my-build-08"
-            assert data[13]["waiting_for"] == "my-build-09"
+            assert data[13]["waiting_for"] == "my-build-08"
             assert data[14]["waiting_for"] == "my-build-09"
             assert data[15]["waiting_for"] == "my-build-09"
             assert data[16]["waiting_for"] == "my-build-09"
-            assert data[17]["waiting_for"] == "my-build-10"
-            assert data[18]["waiting_for"] == "my-build-10"
+            assert data[17]["waiting_for"] == "my-build-09"
+            assert data[18]["waiting_for"] == "my-build-09"
             assert data[19]["waiting_for"] == "my-build-10"
             assert data[20]["waiting_for"] == "my-build-10"
-            for i in range(21, 27):
+            assert data[21]["waiting_for"] == "my-build-10"
+            assert data[22]["waiting_for"] == "my-build-10"
+            assert data[23]["waiting_for"] == "my-build-10"
+            for i in range(24, 30):
                 assert "waiting_for" not in data[i]
                 assert "kernel" in data[i]
 
@@ -335,7 +359,7 @@ def test_submit(config, plan_config, mocker):
     plan.submit()
 
     assert len(plan.builds) == 11
-    assert len(plan.tests) == 27
+    assert len(plan.tests) == 30
 
 
 def test_bake_submit(config, bake_plan_config, mocker):
@@ -356,6 +380,7 @@ def test_bake_submit(config, bake_plan_config, mocker):
             assert data == {
                 "name": "armv7 validation",
                 "description": "Build and test linux kernel for armv7",
+                "is_public": True,
             }
             return {"uid": "my-plan-uid"}
         if (
@@ -405,6 +430,7 @@ def test_bake_plan_extended_config_submit(config, bake_plan_extended_config, moc
             assert data == {
                 "name": "OE RPB tux CI test (LTS)",
                 "description": "A sanity test for OE RPB",
+                "is_public": True,
             }
             return {"uid": "my-plan-uid"}
         if (
