@@ -520,6 +520,7 @@ class Plan(HeadersMixin):
         self.group = kwargs["group"]
         self.args = kwargs
         self.plan = kwargs.get("plan", None)
+        self.is_public = kwargs.get("is_public", True)  # plan public or private
         self.builds = []
         self.tests = []
         self.status = {}
@@ -544,7 +545,11 @@ class Plan(HeadersMixin):
         self.plan = post_request(
             f"{self.url}/plans",
             self.headers,
-            {"name": self.config.name, "description": self.config.description},
+            {
+                "name": self.config.name,
+                "description": self.config.description,
+                "is_public": self.is_public,
+            },
         )["uid"]
 
         # calling respective plan type class to create builds
@@ -561,12 +566,14 @@ class Plan(HeadersMixin):
                             tuxapi_url=self.tuxapi_url,
                             group=self.group,
                             project=self.project,
+                            bios=test.get("bios"),
+                            boot_args=test.get("boot_args"),
                             device=test["device"],
+                            dtb=test.get("dtb"),
                             parameters=test.get("parameters", {}),
                             rootfs=test.get("rootfs"),
                             tests=test.get("tests", []),
                             timeouts=test.get("timeouts"),
-                            boot_args=test.get("boot_args"),
                             wait_for=build.uid,
                         )
                     )
@@ -580,9 +587,13 @@ class Plan(HeadersMixin):
                             tuxapi_url=self.tuxapi_url,
                             group=self.group,
                             project=self.project,
-                            device=test["device"],
-                            kernel=test.get("kernel"),
                             ap_romfw=test.get("ap_romfw"),
+                            bios=test.get("bios"),
+                            boot_args=test.get("boot_args"),
+                            device=test["device"],
+                            dtb=test.get("dtb"),
+                            fip=test.get("fip"),
+                            kernel=test.get("kernel"),
                             mcp_fw=test.get("mcp_fw"),
                             mcp_romfw=test.get("mcp_romfw"),
                             modules=test.get("modules"),
@@ -592,8 +603,6 @@ class Plan(HeadersMixin):
                             scp_romfw=test.get("scp_romfw"),
                             tests=test.get("tests", []),
                             timeouts=test.get("timeouts"),
-                            fip=test.get("fip"),
-                            boot_args=test.get("boot_args"),
                         )
                     )
 
@@ -860,9 +869,13 @@ class Test(HeadersMixin):
     group = attrib()
     project = attrib()
     device = attrib()
-    kernel = attrib(default=None)
+
     ap_romfw = attrib(default=None)
+    boot_args = attrib(default=None)
+    bios = attrib(default=None)
     dtb = attrib(default=None)
+    fip = attrib(default=None)
+    kernel = attrib(default=None)
     mcp_fw = attrib(default=None)
     mcp_romfw = attrib(default=None)
     modules = attrib(default=None)
@@ -870,12 +883,11 @@ class Test(HeadersMixin):
     rootfs = attrib(default=None)
     scp_fw = attrib(default=None)
     scp_romfw = attrib(default=None)
-    fip = attrib(default=None)
     tests = attrib(default=[])
     timeouts = attrib(default=[])
-    boot_args = attrib(default=None)
-    wait_for = attrib(default=None)
+
     uid = attrib(default=None)
+    wait_for = attrib(default=None)
     status = attrib(default={})
     url = attrib(default=None)
 
@@ -888,17 +900,18 @@ class Test(HeadersMixin):
 
     def generate_test_request(self, plan=None):
         data = {
-            "device": self.device,
-            "kernel": self.kernel,
             "ap_romfw": self.ap_romfw,
+            "bios": self.bios,
+            "device": self.device,
             "dtb": self.dtb,
+            "fip": self.fip,
+            "kernel": self.kernel,
             "mcp_fw": self.mcp_fw,
             "mcp_romfw": self.mcp_romfw,
             "parameters": self.parameters,
             "rootfs": self.rootfs,
             "scp_fw": self.scp_fw,
             "scp_romfw": self.scp_romfw,
-            "fip": self.fip,
         }
         if self.modules:
             data["modules"] = self.modules
