@@ -5,7 +5,9 @@ import sys
 import json
 import argparse
 import tuxsuite
+import tuxsuite.exceptions
 
+from tuxsuite.cli.requests import post
 from tuxsuite.cli.utils import (
     error,
     file_or_url,
@@ -38,7 +40,6 @@ def handle_submit(cmdargs, _, config):
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
     print(
-        "*** WARNING: BITBAKE SUPPORT IS EXPERIMENTAL ***\n"
         "Building targets: {} with bitbake from {} source with distro: {} machine: {} arguments".format(
             build.build_definition.targets,
             build.build_definition.sources,
@@ -57,7 +58,11 @@ def handle_submit(cmdargs, _, config):
     if cmdargs.no_wait:
         format_result(build.status, tuxapi_url=build.build_data)
     else:
-        build_result = wait_for_object(build)
+        try:
+            build_result = wait_for_object(build)
+        except tuxsuite.exceptions.Timeout as exc:
+            build_result = False
+            sys.stderr.write(f"Error: {str(exc)}\n")
 
     if cmdargs.download:
         tuxsuite.download.download(build, cmdargs.output_dir)
@@ -68,8 +73,21 @@ def handle_submit(cmdargs, _, config):
         sys.exit(1)
 
 
+def handle_cancel(options, _, config):
+    url = f"/v1/groups/{config.group}/projects/{config.project}/oebuilds/{options.uid}/cancel"
+    ret = post(config, url, data={})
+    print(f"canceling job for {options.uid}")
+
+    if ret.status_code != 200:
+        print(f"unable to cancel oebuild {options.uid}")
+        raise tuxsuite.exceptions.URLNotFound()
+
+    return 0
+
+
 handlers = {
     "submit": handle_submit,
+    "cancel": handle_cancel,
 }
 
 
@@ -147,4 +165,8 @@ def setup_parser(parser):
     )
     bake_cmd_options(t)
 
+    # "bake cancel <uid>"
+    t = parser.add_parser("cancel")
+    t.add_argument("uid")
+
     return sorted(parser._name_parser_map.keys())
