@@ -272,6 +272,63 @@ def handle_cancel(options, _, config):
     return 0
 
 
+def handle_wait(options, _, config):
+    ret = get(
+        config,
+        f"/v1/groups/{config.group}/projects/{config.project}/plans/{options.uid}",
+    )
+    if ret.status_code != 200:
+        raise NotImplementedError()
+
+    data = ret.json()
+    start_builds = data["builds"]["next"]
+    start_tests = data["tests"]["next"]
+    start_oebuilds = data["oebuilds"]["next"]
+    while start_builds or start_tests or start_oebuilds:
+        ret = get(
+            config,
+            f"/v1/groups/{config.group}/projects/{config.project}/plans/{options.uid}",
+            params={
+                "start_builds": start_builds,
+                "start_tests": start_tests,
+                "start_oebuilds": start_oebuilds,
+            },
+        )
+        if ret.status_code != 200:
+            raise NotImplementedError()
+        datan = ret.json()
+        if start_builds:
+            data["builds"]["results"].extend(datan["builds"]["results"])
+            start_builds = datan["builds"]["next"]
+        if start_tests:
+            data["tests"]["results"].extend(datan["tests"]["results"])
+            start_tests = datan["tests"]["next"]
+        if start_oebuilds:
+            data["oebuilds"]["results"].extend(datan["oebuilds"]["results"])
+            start_oebuilds = datan["oebuilds"]["next"]
+
+    data["project"] = config.project
+    plan = tuxsuite.Plan(config, **data)
+    plan.plan = data["uid"]
+    plan.load(plan.get_plan())
+    if plan.builds:
+        for build in plan.builds:
+            build.build_data = f"{plan.url}/builds/{build.uid}"
+
+    wait_for_object(plan)
+
+    for b in chain(
+        plan.passing(),
+        plan.warning(),
+        plan.failing(),
+        plan.errors(),
+        plan.canceled(),
+        plan.unknown(),
+    ):
+        format_plan_result(b, plan._tests_wait_for(b.uid))
+    return 0
+
+
 def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/plans"
     ret = get(config, url)
@@ -389,6 +446,7 @@ def handle_submit(cmdargs, _, config):
 handlers = {
     "get": handle_get,
     "list": handle_list,
+    "wait": handle_wait,
     "submit": handle_submit,
     "cancel": handle_cancel,
 }
@@ -456,6 +514,10 @@ def setup_parser(parser):
     plan_cmd_options(t)
     common_options(t)
 
+    # plan wait <uid>
+    t = parser.add_parser("wait")
+    t.add_argument("uid")
+
     # plan cancel <uid>
     t = parser.add_parser("cancel")
     t.add_argument("uid")
